summaryrefslogtreecommitdiffstats
path: root/kooka/kooka.h
diff options
context:
space:
mode:
Diffstat (limited to 'kooka/kooka.h')
-rw-r--r--kooka/kooka.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/kooka/kooka.h b/kooka/kooka.h
index 84ff1423..634e6c53 100644
--- a/kooka/kooka.h
+++ b/kooka/kooka.h
@@ -84,14 +84,14 @@ protected:
* This function is called when it is time for the app to save its
* properties for session management purposes.
*/
- void saveProperties(KConfig *);
+ void saveProperties(TDEConfig *);
/**
* This function is called when this app is restored. The KConfig
* object points to the session management config file that was saved
* with @ref saveProperties
*/
- void readProperties(KConfig *);
+ void readProperties(TDEConfig *);
private slots:
@@ -84,14 +84,14 @@ protected:
/**
- * This function is called when this app is restored. The KConfig
+ * This function is called when this app is restored. The TDEConfig
* object points to the session management config file that was saved
* with @ref saveProperties